@@ -8,35 +8,29 @@ package Net::LibResolv;
 use strict;
 use warnings;
 
-our $VERSION = '0.02_001';
+our $VERSION = '0.01';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
    res_query
    res_search
-
-   $h_errno
 );
 our %EXPORT_TAGS;
 
-our $h_errno;
-
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
 
-$EXPORT_TAGS{":errors"} = [qw( HOST_NOT_FOUND NO_ADDRESS NO_DATA NO_RECOVERY TRY_AGAIN )];
-
 =head1 NAME
 
 C<Net::LibResolv> - a Perl wrapper around F<libresolv>
 
 =head1 SYNOPSIS
 
- use Net::LibResolv qw( res_query NS_C_IN NS_T_A $h_errno );
+ use Net::LibResolv qw( res_query NS_C_IN NS_T_A );
  use Net::DNS::Packet;
  
  my $answer = res_query( "www.cpan.org", NS_C_IN, NS_T_A );
- defined $answer or die "DNS failure - $h_errno\n";
+ defined $answer or die "DNS failure\n";
  
  foreach my $rr ( Net::DNS::Packet->new( \$answer )->answer ) {
     print $rr->string, "\n";
@@ -64,8 +58,7 @@ information out of it; most likely by using L<Net::DNS>.
 =head2 $answer = res_query( $dname, $class, $type )
 
 Calls the C<res_query(3)> function on the given domain name, class and type
-number. Returns the answer byte buffer on success, or C<undef> on failure. On
-failure sets the value of the C<$h_errno> package variable.
+number. Returns the answer byte buffer on success, or C<undef> on failure.
 
 C<$dname> should be a plain string. C<$class> and C<$type> should be numerical
 codes. See the C<CONSTANTS> section for convenient definitions.
@@ -75,34 +68,13 @@ codes. See the C<CONSTANTS> section for convenient definitions.
 =head2 $answer = res_search( $dname, $class, $type )
 
 Calls the C<res_search(3)> function on the given domain name, class and type
-number. Returns the answer byte buffer on success, or C<undef> on failure. On
-failure sets the value of the C<$h_errno> package variable.
+number. Returns the answer byte buffer on success, or C<undef> on failure.
 
 C<$dname> should be a plain string. C<$class> and C<$type> should be numerical
 codes. See the C<CONSTANTS> section for convenient definitions.
 
 =cut
 
-=head1 VARIABLES
-
-=head2 $h_errno
-
-After an error from C<res_query> or C<res_search>, this variable will be set
-to the error value, as a dual-valued scalar. Its numerical value will be one
-of the error constants (see below); it string value will be an error message
-version of the same (similar to the C<$!> perl core variable).
-
- if( !defined( my $answer = res_query( ... ) ) ) {
-    print "Try again later...\n" if $h_errno == TRY_AGAIN;
- }
-
-Z<>
-
- defined( my $answer = res_query( ... ) ) or
-    die "Cannot res_query() - $h_errno\n";
-
-=cut
-
 =head1 CONSTANTS
 
 =cut
@@ -111,26 +83,16 @@ sub _setup_constants
 {
    my %args = @_;
 
-   my $name   = $args{name};
    my $prefix = $args{prefix};
    my $values = $args{values};
    my $tag    = $args{tag};
 
-   my %name2value = %$values;
-   my %value2name = reverse %name2value;
-
    require constant;
-   constant->import( "$prefix$_" => $name2value{$_} ) for keys %name2value;
+   constant->import( "$prefix$_" => $values->{$_} ) for keys %$values;
 
-   push @EXPORT_OK, map "$prefix$_", keys %name2value;
+   push @EXPORT_OK, map "$prefix$_", keys %$values;
 
-   $EXPORT_TAGS{$tag} = [ map "$prefix$_", keys %name2value ];
-
-   no strict 'refs';
-   *{"${name}_name2value"} = sub { $name2value{uc shift} };
-   *{"${name}_value2name"} = sub { $value2name{+shift} };
-
-   push @EXPORT_OK, "${name}_name2value", "${name}_value2name";
+   $EXPORT_TAGS{$tag} = [ map "$prefix$_", keys %$values ];
 }
 
 # These constants are defined by RFCs, primarily RFC 1035 and friends. We
@@ -145,16 +107,9 @@ Typically only C<NS_C_IN> is actually used, for Internet.
  NS_C_IN NS_C_CHAOS NS_C_HS
  NS_C_INVALD NS_C_NONE NS_C_ANY
 
-=head2 $id = class_name2value( $name )
-
-=head2 $name = class_value2name( $id )
-
-Functions to convert between class names and ID values.
-
 =cut
 
 _setup_constants
-   name   => "class",
    prefix => "NS_C_",
    tag    => ":classes",
    values => {
@@ -175,17 +130,10 @@ type, so only a few are listed here.)
  NS_T_A NS_T_NS NS_T_CNAME NS_T_PTR NS_T_MX NS_T_TXT NS_T_SRV NS_T_AAAA
  NS_T_INVALID NS_T_ANY
 
-=head2 $id = type_name2value( $name )
-
-=head2 $name = type_value2name( $id )
-
-Functions to convert between type names and ID values.
-
 =cut
 
 # The following list shamelessly stolen from <arpa/nameser.h>
 _setup_constants
-   name   => "type",
    prefix => "NS_T_",
    tag    => ":types",
    values => {
@@ -241,24 +189,6 @@ _setup_constants
       ANY      => 255,
    };
 
-=head2 Errors
-
-The following constants define error values for C<$h_errno>.
-
- HOST_NOT_FOUND NO_ADDRESS NO_DATA NO_RECOVERY TRY_AGAIN
-
-The values of C<NO_ADDRESS> and C<NO_DATA> may be the same.
-
-=head1 SEE ALSO
-
-=over 4
-
-=item *
-
-L<Net::DNS> - Perl interface to the DNS resolver
-
-=back
-
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
